@@ -25,7 +25,7 @@ from cmd2 import (
 
 DC_TOOLS = [ 'system-tools', 'dev-tools', 'app-services','dataset-services','dl-model-services','dl-model-training-services',
                 'dlstreamer-services','edge-deployment-services','edge-inference-app-services',
-                'edge-to-cloud-app-services','k8s-tools','intel-dev-tools']
+                'edge-to-cloud-app-services','k8s-services','intel-dev-tools']
 DC_COMMANDS = ['install', 'uninstall', 'enable', 'disable']
 APP_COMMANDS = ['start', 'stop', 'restart']
 
@@ -35,7 +35,7 @@ SUB_TOOLS={
   "app-services":['telemetry','log-anlytics','perf-analysis','video-playback','rtsp-streamer','configs','benchmark-report'],  
   "dataset-services":['intel','partner','public','synthetic'],
   "dl-model-services":['dl-model-tools', 'inference-runtimes', 'model-zoo'],
-  "dl-model-training-services":['data-engineering-tools', 'datasets', 'model-zoo', 'training-framework'],
+  "dl-model-training-services":['data-engineering-tools', 'datasets', 'model-zoo', 'training-frameworks'],
   "dlstreamer-services":['audio-pipelines','dl-streamer-tools','multi-sensory-pipelines','video-pipelines'],
   "edge-deployment-services":['cross-plane','health-check','mass','vpshere-vm'],
   "edge-inference-app-services":['healthcare','industrial','market-places','media','retail','safety-security','transportation'],
@@ -52,7 +52,7 @@ TOOLS={
   "data-engineering-tools":['cvat'],
   "datasets":['emotion-recognition','face-detection','object-detection'],
   "model-zoo":['omz'],
-  "training-framework":['cnvrg','intel-optimized-pytorch','intel-optimized-tensorflow','kubeflow','one-api','sonoma-creek'],
+  "training-frameworks":['cnvrg','intel-optimized-pytorch','intel-optimized-tensorflow','kubeflow','one-api','sonoma-creek'],
   "dl-streamer-tools":['dlstreamer','dlstreamer-pipeline-server','dlstreamer-pipeline-zoo','dlstreamer-pipeline-composer','gst-shark'],
   "healthcare":['brain-tumor-segmentation','monai','openfl'],
   "industrial":['edge-controls-for-industrial','edge-insights-for-amr','edge-insights-for-industrial','industrial-surface-detect-detection','industrial-textline-recognition','rotor-bearing-defect-detector','textile-defect-classifier','weld-porosity-detection'],
@@ -165,7 +165,7 @@ class DC(cmd2.Cmd):
         if len(argsList)>6:
             self.poutput("Invalid Args: {}".format(statement.args))        
             
-        if len(argsList) == 4:
+        if len(argsList) >= 4:
             typeName=argsList[0]
             toolName=argsList[1]
             subtoolName=argsList[2]
